@@ -162,16 +162,19 @@ module Gen = struct
     else fun st -> let r = pint st in r mod (n + 1)
   let int_range a b =
     if b < a then invalid_arg "Gen.int_range";
-    if a >= 0 || b <= 0 then (* range smaller than max_int *)
+    if a >= 0 || b <= 0 then (
+      (* range smaller than max_int *)
+      assert (b-a >= 0);
       fun st -> a + (int_bound (b-a) st)
-    else
+    ) else (
       (* range potentially bigger than max_int: we split on 0 and
          choose the itv wrt to their size ratio *)
       fun st ->
       let f_a = float_of_int a in
       let ratio = (-.f_a) /. (float_of_int b -. f_a) in
-      if Random.float 1. < ratio then - (int_bound a st)
+      if Random.float 1. < ratio then - (int_bound (abs a) st)
       else int_bound b st
+    )
 
   let (--) = int_range
 
@@ -301,6 +304,13 @@ module Gen = struct
     list_repeat n g rand
 
   let generate1 ?(rand=Random.State.make_self_init()) g = g rand
+
+  include Qcheck_ops.Make(struct
+      type nonrec 'a t = 'a t
+      let (>|=) = (>|=)
+      let monoid_product a b = map2 (fun x y -> x,y) a b
+      let (>>=) = (>>=)
+    end)
 end
 
 module Print = struct
@@ -375,6 +385,13 @@ module Iter = struct
     !r
 
   let find p iter = find_map (fun x->if p x then Some x else None) iter
+
+  include Qcheck_ops.Make(struct
+      type nonrec 'a t = 'a t
+      let (>|=) = (>|=)
+      let monoid_product a b = map2 (fun x y -> x,y) a b
+      let (>>=) = (>>=)
+    end)
 end
 
 module Shrink = struct
